==> ejc-ztpcct-impl-3.0.0-20240428.030022-123-sources.jar: com/ejianc/ztpc/bean/ConSchemePlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案编制计划表
 *
 * @author generator
 */
@TableName("ct_con_scheme_plan")
public class ConSchemePlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "specialty_type")
    private Long specialtyType; // 专业分类--字典ct_specialty_type
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value = "execute_state")
    private String executeState; // 执行状态
    @TableField(value = "execute_state_name")
    private String executeStateName; // 执行状态名称
    @TableField(value = "approval_power")
    private String approvalPower; // 批准权限
    @TableField(value = "redact_dept")
    private Long redactDept; // 编制部门
    @TableField(value = "plan_redact_date")
    private Date planRedactDate; // 计划编制时间
    @TableField(value = "redact_finish_date")
    private Date redactFinishDate; // 编制完成时间
    @TableField(value = "org_expert_examine")
    private String orgExpertExamine; // 组织专家审查要求（Y：是，N：否）
    @TableField(value = "cons_time_frame")
    private String consTimeFrame; // 施工时段
    @TableField(value = "finish_cons_scheme_date")
    private Date finishConsSchemeDate; // 完成施工方案时间
    @TableField(value = "project_trait")
    private Long projectTrait; // 分部分项工程特征--字典ct_project_trait
    @TableField(value = "key_point_explain")
    private String keyPointExplain; // 专项施工方案关注重点
    @TableField(value = "outside_code")
    private String outsideCode;//外部编码
    @TableField(value = "location_code")
    private Long locationCode;//区域定位码
    @TableField(value = "mgrp")
    private Long mgrp;//机组


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getSpecialtyType() {
        return specialtyType;
    }

    public void setSpecialtyType(Long specialtyType) {
        this.specialtyType = specialtyType;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public String getExecuteState() {
        return executeState;
    }

    public void setExecuteState(String executeState) {
        this.executeState = executeState;
    }

    public String getExecuteStateName() {
        return executeStateName;
    }

    public void setExecuteStateName(String executeStateName) {
        this.executeStateName = executeStateName;
    }

    public String getApprovalPower() {
        return approvalPower;
    }

    public void setApprovalPower(String approvalPower) {
        this.approvalPower = approvalPower;
    }

    public Long getRedactDept() {
        return redactDept;
    }

    public void setRedactDept(Long redactDept) {
        this.redactDept = redactDept;
    }

    public Date getPlanRedactDate() {
        return planRedactDate;
    }

    public void setPlanRedactDate(Date planRedactDate) {
        this.planRedactDate = planRedactDate;
    }

    public Date getRedactFinishDate() {
        return redactFinishDate;
    }

    public void setRedactFinishDate(Date redactFinishDate) {
        this.redactFinishDate = redactFinishDate;
    }

    public String getOrgExpertExamine() {
        return orgExpertExamine;
    }

    public void setOrgExpertExamine(String orgExpertExamine) {
        this.orgExpertExamine = orgExpertExamine;
    }

    public String getConsTimeFrame() {
        return consTimeFrame;
    }

    public void setConsTimeFrame(String consTimeFrame) {
        this.consTimeFrame = consTimeFrame;
    }

    public Date getFinishConsSchemeDate() {
        return finishConsSchemeDate;
    }

    public void setFinishConsSchemeDate(Date finishConsSchemeDate) {
        this.finishConsSchemeDate = finishConsSchemeDate;
    }

    public Long getProjectTrait() {
        return projectTrait;
    }

    public void setProjectTrait(Long projectTrait) {
        this.projectTrait = projectTrait;
    }

    public String getKeyPointExplain() {
        return keyPointExplain;
    }

    public void setKeyPointExplain(String keyPointExplain) {
        this.keyPointExplain = keyPointExplain;
    }

    public String getOutsideCode() {
        return outsideCode;
    }

    public void setOutsideCode(String outsideCode) {
        this.outsideCode = outsideCode;
    }

    public Long getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(Long locationCode) {
        this.locationCode = locationCode;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
}

==> ejc-ztpcct-impl-3.0.0-20250305.071749-194-sources.jar: com/ejianc/ztpc/bean/ConSchemePlanEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案编制计划表
 *
 * @author generator
 */
@TableName("ct_con_scheme_plan")
public class ConSchemePlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "specialty_type")
    private Long specialtyType; // 专业分类--字典ct_specialty_type
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value = "execute_state")
    private String executeState; // 执行状态
    @TableField(value = "execute_state_name")
    private String executeStateName; // 执行状态名称
    @TableField(value = "approval_power")
    private String approvalPower; // 批准权限
    @TableField(value = "redact_dept")
    private Long redactDept; // 编制部门
    @TableField(value = "plan_redact_date")
    private Date planRedactDate; // 计划编制时间
    @TableField(value = "redact_finish_date")
    private Date redactFinishDate; // 编制完成时间
    @TableField(value = "org_expert_examine")
    private String orgExpertExamine; // 组织专家审查要求（Y：是，N：否）
    @TableField(value = "cons_time_frame")
    private String consTimeFrame; // 施工时段
    @TableField(value = "finish_cons_scheme_date")
    private Date finishConsSchemeDate; // 完成施工方案时间
    @TableField(value = "project_trait")
    private Long projectTrait; // 分部分项工程特征--字典ct_project_trait
    @TableField(value = "key_point_explain")
    private String keyPointExplain; // 专项施工方案关注重点
    @TableField(value = "outside_code")
    private String outsideCode;//外部编码
    @TableField(value = "location_code")
    private Long locationCode;//区域定位码
    @TableField(value = "mgrp")
    private Long mgrp;//机组
    @TableField(value = "compilation_unit")
    private String compilationUnit; //编制单位
    @TableField(value = "review_requirements")
    private String reviewRequirements; //评审要求
    @TableField(value = "project_range")
    private String projectRange; //超过一定规模的危险性较大的分部分项工程范围
    @TableField(value = "memo")
    private String memo; //备注
    @TableField(value = "sub_item_name")
    private String subItemName; //分部分项工程名称


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getSpecialtyType() {
        return specialtyType;
    }

    public void setSpecialtyType(Long specialtyType) {
        this.specialtyType = specialtyType;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public String getExecuteState() {
        return executeState;
    }

    public void setExecuteState(String executeState) {
        this.executeState = executeState;
    }

    public String getExecuteStateName() {
        return executeStateName;
    }

    public void setExecuteStateName(String executeStateName) {
        this.executeStateName = executeStateName;
    }

    public String getApprovalPower() {
        return approvalPower;
    }

    public void setApprovalPower(String approvalPower) {
        this.approvalPower = approvalPower;
    }

    public Long getRedactDept() {
        return redactDept;
    }

    public void setRedactDept(Long redactDept) {
        this.redactDept = redactDept;
    }

    public Date getPlanRedactDate() {
        return planRedactDate;
    }

    public void setPlanRedactDate(Date planRedactDate) {
        this.planRedactDate = planRedactDate;
    }

    public Date getRedactFinishDate() {
        return redactFinishDate;
    }

    public void setRedactFinishDate(Date redactFinishDate) {
        this.redactFinishDate = redactFinishDate;
    }

    public String getOrgExpertExamine() {
        return orgExpertExamine;
    }

    public void setOrgExpertExamine(String orgExpertExamine) {
        this.orgExpertExamine = orgExpertExamine;
    }

    public String getConsTimeFrame() {
        return consTimeFrame;
    }

    public void setConsTimeFrame(String consTimeFrame) {
        this.consTimeFrame = consTimeFrame;
    }

    public Date getFinishConsSchemeDate() {
        return finishConsSchemeDate;
    }

    public void setFinishConsSchemeDate(Date finishConsSchemeDate) {
        this.finishConsSchemeDate = finishConsSchemeDate;
    }

    public Long getProjectTrait() {
        return projectTrait;
    }

    public void setProjectTrait(Long projectTrait) {
        this.projectTrait = projectTrait;
    }

    public String getKeyPointExplain() {
        return keyPointExplain;
    }

    public void setKeyPointExplain(String keyPointExplain) {
        this.keyPointExplain = keyPointExplain;
    }

    public String getOutsideCode() {
        return outsideCode;
    }

    public void setOutsideCode(String outsideCode) {
        this.outsideCode = outsideCode;
    }

    public Long getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(Long locationCode) {
        this.locationCode = locationCode;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public String getCompilationUnit() {
        return compilationUnit;
    }

    public void setCompilationUnit(String compilationUnit) {
        this.compilationUnit = compilationUnit;
    }

    public String getReviewRequirements() {
        return reviewRequirements;
    }

    public void setReviewRequirements(String reviewRequirements) {
        this.reviewRequirements = reviewRequirements;
    }

    public String getProjectRange() {
        return projectRange;
    }

    public void setProjectRange(String projectRange) {
        this.projectRange = projectRange;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getSubItemName() {
        return subItemName;
    }

    public void setSubItemName(String subItemName) {
        this.subItemName = subItemName;
    }
}
